@@ -47,14 +47,14 @@ Pretty printing::
 Decoding JSON::
     
     >>> import simplejson
-    >>> simplejson.loads('["foo", {"bar":["baz", null, 1.0, 2]}]')
-    [u'foo', {u'bar': [u'baz', None, 1.0, 2]}]
-    >>> simplejson.loads('"\\"foo\\bar"')
-    u'"foo\x08ar'
+    >>> simplejson.loads('["foo", {"bar":["baz", null, 1.0, 2]}]') == ["foo", {"bar":["baz", None, 1.0, 2]}]
+    True
+    >>> simplejson.loads('"\\"foo\\bar"') == '"foo\x08ar'
+    True
     >>> from StringIO import StringIO
     >>> io = StringIO('["streaming API"]')
-    >>> simplejson.load(io)
-    [u'streaming API']
+    >>> simplejson.load(io) == ["streaming API"]
+    True
 
 Specializing JSON object decoding::
 
@@ -84,8 +84,8 @@ Extending JSONEncoder::
     '[2.0, 1.0]'
     >>> ComplexEncoder().encode(2 + 1j)
     '[2.0, 1.0]'
-    >>> list(ComplexEncoder().iterencode(2 + 1j))
-    ['[', '2.0', ', ', '1.0', ']']
+    >>> ''.join(ComplexEncoder().iterencode(2 + 1j))
+    '[2.0, 1.0]'
     
 
 Using simplejson from the shell to validate and
@@ -101,7 +101,7 @@ pretty-print::
 Note that the JSON produced by this module's default settings
 is a subset of YAML, so it may be used as a serializer for that as well.
 """
-__version__ = '1.9.3'
+__version__ = '2.0.0'
 __all__ = [
     'dump', 'dumps', 'load', 'loads',
     'JSONDecoder', 'JSONEncoder',
